package M;

$VERSION = 1.000001;

__END__
=head1 NAME

M - M

=head1 DESCRIPTION

  package MyClass;

  use M;

  # write the entire class here by hand

L<Moose> led to L<Mouse> lead to L<Moo> led to L<Mo>.

But INGY's L<Mo> does so little the only way I could see to usefully
do less was to do absolutely nothing. Which M duly does.

=head1 SUPPORT

Since M does absolutely nothing, M should also have a bugtracker that does
absolutely nothing. As such, you are respectfully requested to send bug
reports directly to the author, who will then ignore them entirely.

=head1 AUTHOR

Matt S. Trout (mst) <mst@shadowcat.co.uk>

=head1 COPYRIGHT

Copyright (c) 2011-2012 Matt S. Trout (for what little it's worth)

=head1 LICENSE

This library is free software and may be distributed under the same terms
as perl itself.

=cut
